==> rhapsodie_0.1.0.tar.gz: rhapsodie-0.1.0/inc/alkatraz.h <==
/*************************************************************************}
{ alkatraz.h - common functions                                           }
{                                                                         }
{ (c) Alexey Parfenov, 2011                                               }
{                                                                         }
{ e-mail: zxed@alkatrazstudio.net                                         }
{                                                                         }
{ This library is free software; you can redistribute it and/or           }
{ modify it under the terms of the GNU General Public License             }
{ as published by the Free Software Foundation; either version 3 of       }
{ the License, or (at your option) any later version.                     }
{                                                                         }
{ This library is distributed in the hope that it will be useful,         }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of          }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        }
{ General Public License for more details.                                }
{                                                                         }
{ You may read GNU General Public License at:                             }
{   http://www.gnu.org/copyleft/gpl.html                                  }
{                                                                         }
{ last modified: 14 Jan 2012                                              }
{*************************************************************************/

#ifndef ALKATRAZ_H
#define ALKATRAZ_H

#include <QObject>
#include <stdlib.h>
#include <QHash>

#ifdef Q_OS_SYMBIAN
    #include <e32const.h>
#endif

#define SETERROR(err, data...) lastError=err; emit onError(err, ## data)
#define CHECK(s, err, data...) if(!(s)) {SETERROR(err, ## data); return false;}
#define CHECKV(s, err, data...) if(!(s)) {SETERROR(err, ## data); return;}
#define CHECKB(s, err, data...) if(!(s)) {SETERROR(err, ## data); break;}
#define CHECKN(s, err, data...) if(!(s)) {SETERROR(err, ## data); return -1;}
#define TRY(s, err, data...) try {s;} catch(...){SETERROR(err, ## data); return false;}
#define TRYV(s, err, data...) try {s;} catch(...){SETERROR(err, ## data); return;}
#define TRYB(s, err, data...) try {s;} catch(...){SETERROR(err, ## data); break;}
#define TRYN(s, err, data...) try {s;} catch(...){SETERROR(err, ## data); return -1;}
#define CHECKTRY(s, err, data...) try {CHECK(s, err, ## data);} catch(...) {SETERROR(err, ## data); return false;}
#define CHECKVTRY(s, err, data...) try {CHECKV(s, err, ## data);} catch(...) {SETERROR(err, ## data); return;}
#define CHECKBTRY(s, err, data...) try {CHECKB(s, err, ## data);} catch(...) {SETERROR(err, ## data); break;}
#define CHECKNTRY(s, err, data...) try {CHECKN(s, err, ## data);} catch(...) {SETERROR(err, ## data); return -1;}

#define CONNECT(sender,definition) connect(sender,SIGNAL(definition),SLOT(definition))

#define err_NoError -1

#ifdef Q_OS_SYMBIAN
        const int MAX_PATH_LENGTH = KMaxPath;
#else
    #ifdef WIN32
        const int MAX_PATH_LENGTH = MAX_PATH;
    #else
        const int MAX_PATH_LENGTH = 255; // stub for others
    #endif
#endif

class ErrorHandler
{
protected:
    int lastError;

public:
    ErrorHandler(){resetLastError();}
    int getLastError(){return lastError;}
    void resetLastError(){lastError=err_NoError;}
};

int rnd(int limit);
int sgn(int val);
void sleep(int msecs);
void* safeRealloc(void* mem, qint32 size);

#endif // ALKATRAZ_H

==> rhapsodie_0.1.5.tar.gz: rhapsodie-0.1.5/inc/alkatraz.h <==
/*************************************************************************}
{ alkatraz.h - common functions                                           }
{                                                                         }
{ (c) Alexey Parfenov, 2011                                               }
{                                                                         }
{ e-mail: zxed@alkatrazstudio.net                                         }
{                                                                         }
{ This library is free software; you can redistribute it and/or           }
{ modify it under the terms of the GNU General Public License             }
{ as published by the Free Software Foundation; either version 3 of       }
{ the License, or (at your option) any later version.                     }
{                                                                         }
{ This library is distributed in the hope that it will be useful,         }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of          }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        }
{ General Public License for more details.                                }
{                                                                         }
{ You may read GNU General Public License at:                             }
{   http://www.gnu.org/copyleft/gpl.html                                  }
{                                                                         }
{ last modified: 31 Mar 2012                                              }
{*************************************************************************/

#ifndef ALKATRAZ_H
#define ALKATRAZ_H

#include <QtCore>
#include <stdlib.h>

#ifdef Q_OS_SYMBIAN
    #include <e32const.h>
#endif

#define SETERROR(err, data...) lastError=err; emit onError(err, ## data)
#define CHECK(s, err, data...) if(!(s)) {SETERROR(err, ## data); return false;}
#define CHECKV(s, err, data...) if(!(s)) {SETERROR(err, ## data); return;}
#define CHECKB(s, err, data...) if(!(s)) {SETERROR(err, ## data); break;}
#define CHECKN(s, err, data...) if(!(s)) {SETERROR(err, ## data); return -1;}
#define TRY(s, err, data...) try {s;} catch(...){SETERROR(err, ## data); return false;}
#define TRYV(s, err, data...) try {s;} catch(...){SETERROR(err, ## data); return;}
#define TRYB(s, err, data...) try {s;} catch(...){SETERROR(err, ## data); break;}
#define TRYN(s, err, data...) try {s;} catch(...){SETERROR(err, ## data); return -1;}
#define CHECKTRY(s, err, data...) try {CHECK(s, err, ## data);} catch(...) {SETERROR(err, ## data); return false;}
#define CHECKVTRY(s, err, data...) try {CHECKV(s, err, ## data);} catch(...) {SETERROR(err, ## data); return;}
#define CHECKBTRY(s, err, data...) try {CHECKB(s, err, ## data);} catch(...) {SETERROR(err, ## data); break;}
#define CHECKNTRY(s, err, data...) try {CHECKN(s, err, ## data);} catch(...) {SETERROR(err, ## data); return -1;}

#define CONNECT(sender,definition) connect(sender,SIGNAL(definition),SLOT(definition))

#define err_NoError -1

#ifdef Q_OS_SYMBIAN
        const int MAX_PATH_LENGTH = KMaxPath;
#else
    #ifdef WIN32
        const int MAX_PATH_LENGTH = MAX_PATH;
    #else
        const int MAX_PATH_LENGTH = 255; // stub for others
    #endif
#endif

class ErrorHandler
{
protected:
    int lastError;

public:
    explicit ErrorHandler(){resetLastError();}
    inline int getLastError() const {return lastError;}
    inline void resetLastError(){lastError=err_NoError;}
};

int rnd(int limit);
int sgn(int val);
void sleep(int msecs);
void* safeRealloc(void* mem, qint32 size);

#endif // ALKATRAZ_H
